==> CSNewsClient-v0_0_2_0.zip: NetNews/PostForm.cs <==
/*
PostForm.cs : The WinForm cord to post the news article. 
 
Copyright (c) 2005 CSamura
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using TestWeb;

namespace NetNews
{
	/// <summary>
	/// PostForm ̊Tv̐łB
	/// </summary>
	public class PostForm : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.Button btnPostArticle;
		private System.Windows.Forms.TextBox txtName;
		private System.Windows.Forms.TextBox txtAddress;
		private System.Windows.Forms.TextBox txtGroups;
		private System.Windows.Forms.TextBox txtSubject;
		private System.Windows.Forms.TextBox txtBody;
		/// <summary>
		/// KvȃfUCiϐłB
		/// </summary>
		private System.ComponentModel.Container components = null;

		public PostForm()
		{
			//
			// Windows tH[ fUCi T|[gɕKvłB
			//
			InitializeComponent();

			//
			// TODO: InitializeComponent ĂяǒɁARXgN^ R[hǉĂB
			//
		}

		/// <summary>
		/// gpĂ郊\[XɌ㏈s܂B
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows tH[ fUCiŐꂽR[h 
		/// <summary>
		/// fUCi T|[gɕKvȃ\bhłB̃\bh̓e
		/// R[h GfB^ŕύXȂłB
		/// </summary>
		private void InitializeComponent()
		{
			this.label1 = new System.Windows.Forms.Label();
			this.txtName = new System.Windows.Forms.TextBox();
			this.label2 = new System.Windows.Forms.Label();
			this.txtAddress = new System.Windows.Forms.TextBox();
			this.label3 = new System.Windows.Forms.Label();
			this.txtGroups = new System.Windows.Forms.TextBox();
			this.label4 = new System.Windows.Forms.Label();
			this.txtSubject = new System.Windows.Forms.TextBox();
			this.btnPostArticle = new System.Windows.Forms.Button();
			this.txtBody = new System.Windows.Forms.TextBox();
			this.SuspendLayout();
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(32, 8);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(128, 24);
			this.label1.TabIndex = 0;
			this.label1.Text = "O(&N)";
			// 
			// txtName
			// 
			this.txtName.Location = new System.Drawing.Point(184, 8);
			this.txtName.Name = "txtName";
			this.txtName.Size = new System.Drawing.Size(400, 19);
			this.txtName.TabIndex = 1;
			this.txtName.Text = "";
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(32, 40);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(128, 23);
			this.label2.TabIndex = 2;
			this.label2.Text = "[AhX(&A)";
			// 
			// txtAddress
			// 
			this.txtAddress.Location = new System.Drawing.Point(184, 40);
			this.txtAddress.Name = "txtAddress";
			this.txtAddress.Size = new System.Drawing.Size(400, 19);
			this.txtAddress.TabIndex = 4;
			this.txtAddress.Text = "";
			// 
			// label3
			// 
			this.label3.Location = new System.Drawing.Point(32, 72);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(128, 23);
			this.label3.TabIndex = 5;
			this.label3.Text = "j[XO[v(&G)";
			// 
			// txtGroups
			// 
			this.txtGroups.Location = new System.Drawing.Point(184, 72);
			this.txtGroups.Name = "txtGroups";
			this.txtGroups.Size = new System.Drawing.Size(400, 19);
			this.txtGroups.TabIndex = 6;
			this.txtGroups.Text = "";
			// 
			// label4
			// 
			this.label4.Location = new System.Drawing.Point(32, 104);
			this.label4.Name = "label4";
			this.label4.Size = new System.Drawing.Size(128, 23);
			this.label4.TabIndex = 7;
			this.label4.Text = "薼(&S)";
			// 
			// txtSubject
			// 
			this.txtSubject.Location = new System.Drawing.Point(184, 104);
			this.txtSubject.Name = "txtSubject";
			this.txtSubject.Size = new System.Drawing.Size(400, 19);
			this.txtSubject.TabIndex = 8;
			this.txtSubject.Text = "";
			// 
			// btnPostArticle
			// 
			this.btnPostArticle.Location = new System.Drawing.Point(216, 136);
			this.btnPostArticle.Name = "btnPostArticle";
			this.btnPostArticle.Size = new System.Drawing.Size(224, 24);
			this.btnPostArticle.TabIndex = 9;
			this.btnPostArticle.Text = "M";
			this.btnPostArticle.Click += new System.EventHandler(this.btnPostArticle_Click);
			// 
			// txtBody
			// 
			this.txtBody.Location = new System.Drawing.Point(8, 168);
			this.txtBody.Multiline = true;
			this.txtBody.Name = "txtBody";
			this.txtBody.Size = new System.Drawing.Size(576, 240);
			this.txtBody.TabIndex = 10;
			this.txtBody.Text = "";
			// 
			// PostForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 12);
			this.ClientSize = new System.Drawing.Size(592, 414);
			this.Controls.Add(this.txtBody);
			this.Controls.Add(this.btnPostArticle);
			this.Controls.Add(this.txtSubject);
			this.Controls.Add(this.label4);
			this.Controls.Add(this.txtGroups);
			this.Controls.Add(this.label3);
			this.Controls.Add(this.txtAddress);
			this.Controls.Add(this.label2);
			this.Controls.Add(this.txtName);
			this.Controls.Add(this.label1);
			this.Name = "PostForm";
			this.Text = "PostForm";
			this.ResumeLayout(false);

		}
		#endregion

		private void btnPostArticle_Click(object sender, System.EventArgs e)
		{
			NewsArticle a = new NewsArticle();
			string b = a.BeforePost(txtName.Text, txtAddress.Text,
				txtGroups.Text, txtSubject.Text, txtBody.Text);
			MessageBox.Show(b);
			NNTPClient newsc = new NNTPClient();
			newsc.NewsConnect("msnews.microsoft.com", 119);
			newsc.Post(b);
			newsc.NewsDisconnect();
		}
	}
}

==> CSNewsClient-v0_0_2_78.zip: NetNews/PostForm.cs <==
/*
PostForm.cs : The WinForm cord to post the news article. 
 
Copyright (c) 2005 CSamura
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using CSamura.NNTP;

namespace CSamura.Forms
{
	/// <summary>
	/// PostForm ̊Tv̐łB
	/// </summary>
	public class PostForm : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.Button btnPostArticle;
		private System.Windows.Forms.TextBox txtName;
		private System.Windows.Forms.TextBox txtAddress;
		private System.Windows.Forms.TextBox txtGroups;
		private System.Windows.Forms.TextBox txtSubject;
		private System.Windows.Forms.TextBox txtBody;
		/// <summary>
		/// KvȃfUCiϐłB
		/// </summary>
		private System.ComponentModel.Container components = null;

		public PostForm()
		{
			//
			// Windows tH[ fUCi T|[gɕKvłB
			//
			InitializeComponent();

			//
			// TODO: InitializeComponent ĂяǒɁARXgN^ R[hǉĂB
			//
		}

		/// <summary>
		/// gpĂ郊\[XɌ㏈s܂B
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows tH[ fUCiŐꂽR[h 
		/// <summary>
		/// fUCi T|[gɕKvȃ\bhłB̃\bh̓e
		/// R[h GfB^ŕύXȂłB
		/// </summary>
		private void InitializeComponent()
		{
			this.label1 = new System.Windows.Forms.Label();
			this.txtName = new System.Windows.Forms.TextBox();
			this.label2 = new System.Windows.Forms.Label();
			this.txtAddress = new System.Windows.Forms.TextBox();
			this.label3 = new System.Windows.Forms.Label();
			this.txtGroups = new System.Windows.Forms.TextBox();
			this.label4 = new System.Windows.Forms.Label();
			this.txtSubject = new System.Windows.Forms.TextBox();
			this.btnPostArticle = new System.Windows.Forms.Button();
			this.txtBody = new System.Windows.Forms.TextBox();
			this.SuspendLayout();
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(32, 8);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(128, 24);
			this.label1.TabIndex = 0;
			this.label1.Text = "O(&N)";
			// 
			// txtName
			// 
			this.txtName.Location = new System.Drawing.Point(184, 8);
			this.txtName.Name = "txtName";
			this.txtName.Size = new System.Drawing.Size(400, 19);
			this.txtName.TabIndex = 1;
			this.txtName.Text = "";
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(32, 40);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(128, 23);
			this.label2.TabIndex = 2;
			this.label2.Text = "[AhX(&A)";
			// 
			// txtAddress
			// 
			this.txtAddress.Location = new System.Drawing.Point(184, 40);
			this.txtAddress.Name = "txtAddress";
			this.txtAddress.Size = new System.Drawing.Size(400, 19);
			this.txtAddress.TabIndex = 4;
			this.txtAddress.Text = "";
			// 
			// label3
			// 
			this.label3.Location = new System.Drawing.Point(32, 72);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(128, 23);
			this.label3.TabIndex = 5;
			this.label3.Text = "j[XO[v(&G)";
			// 
			// txtGroups
			// 
			this.txtGroups.Location = new System.Drawing.Point(184, 72);
			this.txtGroups.Name = "txtGroups";
			this.txtGroups.Size = new System.Drawing.Size(400, 19);
			this.txtGroups.TabIndex = 6;
			this.txtGroups.Text = "";
			// 
			// label4
			// 
			this.label4.Location = new System.Drawing.Point(32, 104);
			this.label4.Name = "label4";
			this.label4.Size = new System.Drawing.Size(128, 23);
			this.label4.TabIndex = 7;
			this.label4.Text = "薼(&S)";
			// 
			// txtSubject
			// 
			this.txtSubject.Location = new System.Drawing.Point(184, 104);
			this.txtSubject.Name = "txtSubject";
			this.txtSubject.Size = new System.Drawing.Size(400, 19);
			this.txtSubject.TabIndex = 8;
			this.txtSubject.Text = "";
			// 
			// btnPostArticle
			// 
			this.btnPostArticle.Location = new System.Drawing.Point(216, 136);
			this.btnPostArticle.Name = "btnPostArticle";
			this.btnPostArticle.Size = new System.Drawing.Size(224, 24);
			this.btnPostArticle.TabIndex = 9;
			this.btnPostArticle.Text = "M";
			this.btnPostArticle.Click += new System.EventHandler(this.btnPostArticle_Click);
			// 
			// txtBody
			// 
			this.txtBody.Location = new System.Drawing.Point(8, 168);
			this.txtBody.Multiline = true;
			this.txtBody.Name = "txtBody";
			this.txtBody.Size = new System.Drawing.Size(576, 240);
			this.txtBody.TabIndex = 10;
			this.txtBody.Text = "";
			// 
			// PostForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 12);
			this.ClientSize = new System.Drawing.Size(592, 414);
			this.Controls.Add(this.txtBody);
			this.Controls.Add(this.btnPostArticle);
			this.Controls.Add(this.txtSubject);
			this.Controls.Add(this.label4);
			this.Controls.Add(this.txtGroups);
			this.Controls.Add(this.label3);
			this.Controls.Add(this.txtAddress);
			this.Controls.Add(this.label2);
			this.Controls.Add(this.txtName);
			this.Controls.Add(this.label1);
			this.Name = "PostForm";
			this.Text = "PostForm";
			this.ResumeLayout(false);

		}
		#endregion

		private void btnPostArticle_Click(object sender, System.EventArgs e)
		{
			NewsArticle a = new NewsArticle(txtName.Text, txtAddress.Text,
				txtGroups.Text, txtSubject.Text, txtBody.Text);
			//string b = a.BeforePost(txtName.Text, txtAddress.Text,
			//	txtGroups.Text, txtSubject.Text, txtBody.Text);
			string post = a.BeforePost();
			//MessageBox.Show(post);
			
			string session = "";
			NNTPClient newsc = new NNTPClient();
			session += newsc.NewsConnect("msnews.microsoft.com", 119);
			session += newsc.Post(post);
			session += newsc.NewsDisconnect();

			MessageBox.Show(session);
		}
	}
}
